@@ -180,7 +180,9 @@ class BIG:
             self._check_token()
         url = self._get_url(path)
         response = self.session.post(url, json=data)
-        if response.status_code != 200 and response.status_code != 201:
+        if (response.status_code != 200 and
+                response.status_code != 201 and
+                response.status_code != 202):
             raise RESTAPIError(response, self.debug)
         return RESTObject(response.json())
 
